/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_3Q_HPP_
#define _HEAVY_CONTEXT_WSTD_3Q_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSlice.h"
#include "HvControlIf.h"
#include "HvControlSystem.h"
#include "HvMath.h"
#include "HvControlBinop.h"
#include "HvSignalVar.h"
#include "HvControlCast.h"
#include "HvControlUnop.h"
#include "HvSignalBiquad.h"
#include "HvSignalLine.h"
#include "HvControlVar.h"

class Heavy_WSTD_3Q : public HeavyContext {

 public:
  Heavy_WSTD_3Q(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_3Q();

  const char *getName() override { return "WSTD_3Q"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 6; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_35jiVoDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rTaQUM2Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2J2YYuHz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FgWI582P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hGXWousQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_J7c8s9rL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CwAX2thZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_1NLGWZV7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lLOD0VAU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pHbgFsPB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_TU9kde7j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7rM6cmbq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h1y2Rpdt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_czFTbuFi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aeBJ3mKI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YG7To4RO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CaNenXIl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uBwbRacQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mvhSTzCi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZFOyCWsJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_OXh4huGs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ytl09HDO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QH1EHqkG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_31IhSCFo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vAziwhJp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4jWHMlR4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jeZ2zFR3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_USEEBLI8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wIfUkiTX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KJWBaAm7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YCDxk4jP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RZyVcJhy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_abY7qaXo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_No7WwuUP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MMQSgkIc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kch4erE6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NfTCUW1l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_avu6uxI1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wgLHJzLO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CZD55N3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XRyhNvcP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hEzpGjOQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X1inKnCT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_aHCI6pMj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pI5xzTa5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kxlTuy3X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SpNT3PPe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9mlsy2dH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OeFF2vJv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UgFWtodM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xaNEvmAe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IPGzfuuf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A23e1Wt2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TE0hWuFi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vcDBbsZw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gFtckCRE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_U9Taqq2Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hruw8TQ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y4AxY5RG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YgDfqec2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QJwUQev1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oCyEnA0a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ra84uwbt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MXKXLBE5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZSIpY4n2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rgbVcEgF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JJZzpyLg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KdnLkrGz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xiNaaaJs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nW5TwM80_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wt9fOPm7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0oZ2M6In_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_szEfeUmh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3ulf4ZQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NMyt1sMy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b7id82Qe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cjoJNF8k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_888QLQfq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_13Goj8qS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_43PBrehv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZOsv9dwg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_gJqQFZ0k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NPWlq3bG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_dRKGtAGs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pCEforIK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_QZ8zZwaI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_7XnTHPWb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_AVk4fVAJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vzmfNFSc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xcjfsnJO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5OrLqyVK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_vnqn0UWw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hUBZz1FT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_9Ymip5dv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_io8tlb5f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c2e7UUSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EYwk0gy9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GyCK9FI4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j0f3zDRR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b0Zp1n3h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_gM4x3jIP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_LWyGyQFj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5BJJbojh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9vvVBRCd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5whiZkKI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_83YzsKOv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4b2b7bh2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_GzAOudKK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_KIaBe7tR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C7tbjDbl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5AYpUKni_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Al6j2xqz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HlLPy2Tz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jrxJcsfZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iHnWkYA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XLZ1o6aJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qaFOePTO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LtMyUSOM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_518fNBl4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rRmhCvQ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M13O2YrF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PSiPnIeG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PHRvcuge_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iPW2MaEX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uBdm1D1T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_e4WfEkvJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H7qmrniN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zp78cBLe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Vb9dLI7G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_4RAKP9sB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_WjDPkoLt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fHM5YKVR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DOCJ21uk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CQ24WrF3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jV7IUaWP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xWslxNuI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_shGjF842_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZZdCMTjf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LZRbxp0z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W0O5hpXc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T92cnXzS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8lCcjCmR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zP8UIOPX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Mu78kELg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MmRmkjBr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sfM09w6m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0SGP9kfz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5p2P0uSm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3kygDY0t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4KjaNM2G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HdsJcuPc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vRkioUL2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rZ4akLMC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0xIXOSZk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NlqVGD6K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vuaZMRae_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0PnzQOq5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2TM0gO9o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_CdGeV0FV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KRtyns0a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pN5OX3ji_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VFedBJq3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SsyP4nZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RpAYCLZA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_uJ8BSCsC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_a8k9iDL7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lQXBqGPA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9XMWOlRk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q1280NFS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eTjRUZUc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o5NHEm4N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uJve27a2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YvOBrzE3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lGbQqbet_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AjRu19oh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cqm8FLke_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_L80f7Lq4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FpSRxUO0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bk2eYhHE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9jXD3u0S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xuUm0qc6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7ackFWCU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_m7GNjEPZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5loSGAs9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7vfb4G3I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b9uvRujC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iDY7l7pv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YVjmmcbD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5gfgqnVd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aNNg9LQd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sE6jQBGQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f3TAmgja_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u37EFmAH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7vH5f0Ql_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_elos98Hk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qE6uPMsK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lzD0Ztku_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7tQtUAWk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NJ28XbwF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lrLQSvGZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SRyD4Cae_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9P8VThHD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GxPvptu2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IAxZ6KVQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jXYdMNiB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0cfSoDlm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GvKkYBHq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_UfdWFS1y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_yKImrlwj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4XajmBTY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7ZCFYPAb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mChKSvu7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t134N6QK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3WV3VUhD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_n22DpZvE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_69h4dxby_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9fCgaz0F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ad6p63AB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kAp2HeG8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dY7KdToX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QsHze980_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uixrIlCN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BaLz9QQJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jefOKAhh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e3g1YtDP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HquFjcyf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tGcAKG5l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_weUNpxhA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CAmzgc6s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8y4bYaWD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r4V3CACJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rRqnMS1S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QpAM4GsI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_quelAiIa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AklzI4FE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2ry5Vc6i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qKYk2b7g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_w8mvTjhw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_nR9npK3e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_iJA6jmJm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TPbDRWcc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cCtQZyZV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nrNTwTYx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kh1Sw6Q4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YkACgtMt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0tmO8yHj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1uj6xGl6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7sSEALeJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EYfmDCKx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YZuxdx4e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1q0KI9DT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8v1go96R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8NUsWozA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a7Y3ZRz0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CN1S1Npi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a0f17LBD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kbc2ANef_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GaE2EWLD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HwSzn43w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vCj5QGlE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Qfkv7iRG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tZrep4g2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vQgfWTP3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nCXCPpLo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6789kCV4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rtRHGwhU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_TUC8Ge9C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MLmOMhgH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_qv4rmsVh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jI2Bt3XH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kve66j0F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_OX4r5wis_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f3Ia2pui_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9Bh45aOa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YpOkQ4Aa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lKd2iibL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xj8BsByx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gj6hG2H5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ha1zXYti_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lpTJ77zX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BKZn3vrf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_98gulf6V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xf1SwPcH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rQpFKBjQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_85AICjYl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L6LzrufE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cabxLXcC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bdCjf0Gz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_biel8HZa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bpcFiTHq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_apB8sDeI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0K1iwNZs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aGndHXoQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5PcPvaNu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dt3AIHDf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NXX55Rhv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4xb8GILO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KHmiSTP2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KwlCSsHc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X0o5tSch_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iHdbMRf2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2wkAxd9l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ALpChMdM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KrGpEpyr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gSCdCBow_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9DnhkZ8J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J0E098Ih_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BBaWWhjv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wPyNHSWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MbYwRA0C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tGq437s7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2JymY2Il_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T0EpB9ff_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tr39p44Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QeMnTq5a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5tLA1A91_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qyz6vB9p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_aHZbj0Q8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kZfsAkgL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qavozisU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cwc2ud88_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eqNlctrc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rPLCKq6n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J5CGRC0p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H4Bn85n5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ReFoYBI8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IDyp7lAz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_O7SaV4I2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_duSwgZXL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kecqOJZ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zjVgJhXc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TNLAIjXa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XXvmuJRk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bBydKueh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M4B7L4Yw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gPwcMXoD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s6XBMeTq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zCQfEror_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ECzuJvZC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5MibBMKT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_4XkxXTw2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hckobwao_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_otvSQwZI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_cEVT3Ocx_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ky4kLRaG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tCftTaoj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_qLU3QZXj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_c0EOQrN2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_aIESo4OP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wipCLO1P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VXG9ruxp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JVEgsp1y_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_keJn3jpK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Y3qigsJd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_vPHfrQBN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nj36Mqd3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JMu68f3q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9nwTJitx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_14rcNoDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y3VtVw8p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hE4YmDaI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_IXilJkfI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Rvj931Xb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8MsL4YeY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_utP868Az_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TBOYJZCb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rwpUd3Zd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jauKMDZm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Fbrt8RIn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_PkLOmDK8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mlnqTgNm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_POSlBOmj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QPGZlUw8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1KMi0gbV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a8uolj6C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JdvZUWg2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Hc2YN7k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LRwFRjTn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_30hwd60o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h02rU6dE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HMwpzzRg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t0qKIjxx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6LFYHMhs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IiUVrSGD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gJczXXZ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_H5qZ6lMC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fT7z9UJ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4WwniEur_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qdsw79KF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_eF8ewyKQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_cCMHmzl0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ULqjmkYR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hhLLRrI4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OdOirFN0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LUuCuSfl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UZMvgmW1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ICgWFNmf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0jMbNmjg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2A5Eij0Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XS98BV6A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WZZvItAi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kUw0IQKb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e58iXSbA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3mIYrWxN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dnxIiJep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_e8xg9Tw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_70Z3p7Rd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cLtY0BAk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RzxWCrqZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZMAMLzLV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YRsUELiu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uNQGZvv3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6VzDlMzj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pIe8z99m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dqQZDRA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wuGb2KgT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IueCaYZn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jUluczVB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JoqR7H98_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_eOUhAmBJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lgyaCUzS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_up0LDWes_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wGlS3cEk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9GGD1mRS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MeHYnA4b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_kX1uzi3M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_KO75aeLS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ao7EOnhj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CimvbX5i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pz37P1l0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hCj2HJ77_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pxzT2AiT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fLo6Pr0Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5jl0lw4A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VgIMbLFG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VuZG26U0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UtdxR2jt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dmHTAZx9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GuzmVPNU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UnyDzYPR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LFlbuNZU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xSn4uZhy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ReRMJs2m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_TlICQb22_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kPrElmdT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rx5xBBnW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6usUjnpT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZovJl7xW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OQzKP7Nl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zH54a3uS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QJcQHYL0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3LtrYC24_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_92Ktd29H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s00l4tke_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GbaMFKW2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_waURp0gK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6DC7pQxS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6GD2e5Nc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7p8ZNdDv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_weWttrAY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_96WdwL6s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LXPC2MkB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UNnGqkbG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QqVkRmAF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_igKgbNPP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y1GFTc4w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Kiz7XWPa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NrOqlg5y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_lKxY2ve8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_26OpIcLt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZNuvAHYA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XrA2LFa9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PK5Tmgaf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BAA2LSoN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SDbyB1r7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_CSDT6ifU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Dzeif7nx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lqEpwUqb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rzy3WLti_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3d9v9Xcb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MTymP76J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YibmEURJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UMWj3TOW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0p5JVyRR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NOECv487_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gRZ2BypM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Mi4B3S4i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V4MtECvX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dddBDJHg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xdplpNl8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qpj4gnNU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j4rQswEs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QZgTraHk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EszGlR5I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zXGqFjQN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dHeJODCz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hF8pzdXm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2P4FHBDw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_P0eEmcJy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_kPH3gTuE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_iW4iUUjv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lA0Nq2kt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EvD5o6Aa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PSUooRHR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m8RCg67c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LOinEyow_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0SdNVL14_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GIEyP9B0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wl20k4VL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NKaK6w32_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uHGc1W7B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sa0r9GBI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SPfwY9vI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KXBdHrOJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RKFOpARX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xeBOv25g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7AnrnJCL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OyPW2CCg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_erKGFCLp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_e58OEQrh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SYC05m5Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BiYL51Q6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TIXPuhze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8r7M7xlm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_htdLHSqO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qzwrMRS0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MJ7bsSBf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_S3cMBvEj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_GNo1QtUm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_U8Xp1rTx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n5XxC71M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rd4Sbo0R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VXnQcPeH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MGULSpPX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xFUbW4WF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pOlNGK8i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0jKw7mI2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QJeUcO1K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G4NWpP1c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3whfl2k6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r5OCWNu3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3QKzTCq8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qFHsjrrQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KgAXFtJV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uAqeWiu1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xCLWRGTv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vLa7v3xh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fmWkQxHN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IX3jnT5A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kfGaRJdd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RcxbrAD1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eXrOYwB8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1oN7x6HA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_quTNmeA1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1S9gv0Jq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VBnv8PAd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PCfeeOoa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MaIm6KIq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZBjtXVW4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zQsbEgWC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lE7jqGYa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DLogvRyd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6itgj6Wy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TyfvJGza_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8XHo6kNt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NLZb45dK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sJT1hcyi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_67HGSACL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pDWYruV5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7yJL9a4z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Z8mez8Mb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rRdPSd2h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GLOjtTGu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3If2TjRj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hMa4mTR2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1LB4kwFw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SNX3asYW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xYjD0iqC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ABNeBZCK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Se0RsNFt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PlVTtVTF_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_juIJ1bq3;
  SignalLine sLine_HSBlfto4;
  SignalLine sLine_k3cMVEUZ;
  SignalLine sLine_mC5qFVyT;
  SignalLine sLine_zxaTfkul;
  SignalBiquad sBiquad_s_FaEjAeYp;
  SignalLine sLine_5UTUSTPe;
  SignalLine sLine_0dv8q0TN;
  SignalLine sLine_10gBQTkR;
  SignalLine sLine_A0WDN8Yk;
  SignalBiquad sBiquad_s_GejiYPJV;
  SignalLine sLine_2kjBMG0s;
  SignalLine sLine_J1GxVKre;
  SignalLine sLine_NtFUxcRi;
  SignalLine sLine_zKKNZFmj;
  SignalLine sLine_oEfaW6mc;
  SignalBiquad sBiquad_s_uMocLMLe;
  SignalLine sLine_I7hwoE8y;
  SignalLine sLine_w0Pwbzkq;
  SignalLine sLine_jwODPWiI;
  SignalLine sLine_Gt25HlmX;
  SignalLine sLine_26lIDdD7;
  SignalBiquad sBiquad_s_76qvNynj;
  SignalLine sLine_rAIke8YP;
  SignalLine sLine_NmFyk9xE;
  SignalLine sLine_SGLRmN8v;
  SignalLine sLine_0ndUEwve;
  SignalBiquad sBiquad_s_4EkTAIb9;
  SignalLine sLine_iYK0Mw9A;
  SignalLine sLine_ie1TZBzw;
  SignalLine sLine_Z3vvWvgs;
  SignalLine sLine_CcnaJ4Ex;
  SignalLine sLine_L7tnfZDQ;
  SignalBiquad sBiquad_s_awTxZnc4;
  ControlVar cVar_35jiVoDp;
  ControlVar cVar_rTaQUM2Y;
  ControlVar cVar_2J2YYuHz;
  ControlVar cVar_FgWI582P;
  ControlSlice cSlice_J7c8s9rL;
  ControlVar cVar_CwAX2thZ;
  ControlVar cVar_lLOD0VAU;
  ControlIf cIf_pHbgFsPB;
  ControlIf cIf_TU9kde7j;
  ControlBinop cBinop_h1y2Rpdt;
  ControlBinop cBinop_czFTbuFi;
  ControlBinop cBinop_CaNenXIl;
  ControlBinop cBinop_uBwbRacQ;
  ControlBinop cBinop_ZFOyCWsJ;
  ControlIf cIf_OXh4huGs;
  ControlBinop cBinop_ytl09HDO;
  ControlBinop cBinop_QH1EHqkG;
  ControlBinop cBinop_vAziwhJp;
  ControlBinop cBinop_4jWHMlR4;
  ControlBinop cBinop_jeZ2zFR3;
  ControlVar cVar_RZyVcJhy;
  ControlIf cIf_abY7qaXo;
  ControlIf cIf_No7WwuUP;
  ControlBinop cBinop_Kch4erE6;
  ControlBinop cBinop_NfTCUW1l;
  ControlBinop cBinop_CZD55N3j;
  ControlBinop cBinop_XRyhNvcP;
  ControlBinop cBinop_X1inKnCT;
  ControlIf cIf_aHCI6pMj;
  ControlBinop cBinop_pI5xzTa5;
  ControlBinop cBinop_kxlTuy3X;
  ControlBinop cBinop_9mlsy2dH;
  ControlBinop cBinop_OeFF2vJv;
  ControlBinop cBinop_UgFWtodM;
  ControlVar cVar_vcDBbsZw;
  ControlIf cIf_gFtckCRE;
  ControlIf cIf_U9Taqq2Q;
  ControlBinop cBinop_y4AxY5RG;
  ControlBinop cBinop_YgDfqec2;
  ControlBinop cBinop_ra84uwbt;
  ControlBinop cBinop_MXKXLBE5;
  ControlBinop cBinop_rgbVcEgF;
  ControlIf cIf_JJZzpyLg;
  ControlBinop cBinop_KdnLkrGz;
  ControlBinop cBinop_xiNaaaJs;
  ControlBinop cBinop_wt9fOPm7;
  ControlBinop cBinop_0oZ2M6In;
  ControlBinop cBinop_szEfeUmh;
  ControlIf cIf_888QLQfq;
  ControlSlice cSlice_43PBrehv;
  ControlVar cVar_ZOsv9dwg;
  ControlSlice cSlice_dRKGtAGs;
  ControlVar cVar_pCEforIK;
  ControlSlice cSlice_AVk4fVAJ;
  ControlVar cVar_vzmfNFSc;
  ControlSlice cSlice_vnqn0UWw;
  ControlVar cVar_hUBZz1FT;
  ControlBinop cBinop_9vvVBRCd;
  ControlBinop cBinop_83YzsKOv;
  ControlBinop cBinop_4b2b7bh2;
  ControlBinop cBinop_C7tbjDbl;
  ControlBinop cBinop_5AYpUKni;
  ControlBinop cBinop_Al6j2xqz;
  ControlBinop cBinop_HlLPy2Tz;
  ControlBinop cBinop_jrxJcsfZ;
  ControlVar cVar_iHnWkYA9;
  ControlBinop cBinop_XLZ1o6aJ;
  ControlBinop cBinop_qaFOePTO;
  ControlBinop cBinop_LtMyUSOM;
  ControlBinop cBinop_518fNBl4;
  ControlBinop cBinop_rRmhCvQ8;
  ControlBinop cBinop_M13O2YrF;
  ControlBinop cBinop_PSiPnIeG;
  ControlBinop cBinop_iPW2MaEX;
  ControlVar cVar_uBdm1D1T;
  ControlVar cVar_e4WfEkvJ;
  ControlBinop cBinop_DOCJ21uk;
  ControlBinop cBinop_CQ24WrF3;
  ControlBinop cBinop_jV7IUaWP;
  ControlBinop cBinop_shGjF842;
  ControlBinop cBinop_ZZdCMTjf;
  ControlBinop cBinop_LZRbxp0z;
  ControlBinop cBinop_W0O5hpXc;
  ControlBinop cBinop_T92cnXzS;
  ControlBinop cBinop_8lCcjCmR;
  ControlBinop cBinop_pN5OX3ji;
  ControlBinop cBinop_SsyP4nZR;
  ControlBinop cBinop_RpAYCLZA;
  ControlBinop cBinop_lQXBqGPA;
  ControlBinop cBinop_9XMWOlRk;
  ControlBinop cBinop_q1280NFS;
  ControlBinop cBinop_eTjRUZUc;
  ControlBinop cBinop_o5NHEm4N;
  ControlBinop cBinop_uJve27a2;
  ControlBinop cBinop_YvOBrzE3;
  ControlBinop cBinop_AjRu19oh;
  ControlVar cVar_cqm8FLke;
  ControlVar cVar_L80f7Lq4;
  ControlVar cVar_FpSRxUO0;
  ControlBinop cBinop_7vfb4G3I;
  ControlBinop cBinop_b9uvRujC;
  ControlBinop cBinop_iDY7l7pv;
  ControlBinop cBinop_5gfgqnVd;
  ControlBinop cBinop_aNNg9LQd;
  ControlBinop cBinop_sE6jQBGQ;
  ControlBinop cBinop_f3TAmgja;
  ControlBinop cBinop_u37EFmAH;
  ControlBinop cBinop_7ZCFYPAb;
  ControlBinop cBinop_t134N6QK;
  ControlBinop cBinop_3WV3VUhD;
  ControlBinop cBinop_9fCgaz0F;
  ControlBinop cBinop_ad6p63AB;
  ControlBinop cBinop_kAp2HeG8;
  ControlBinop cBinop_dY7KdToX;
  ControlBinop cBinop_QsHze980;
  ControlBinop cBinop_BaLz9QQJ;
  ControlBinop cBinop_e3g1YtDP;
  ControlBinop cBinop_HquFjcyf;
  ControlBinop cBinop_weUNpxhA;
  ControlBinop cBinop_CAmzgc6s;
  ControlBinop cBinop_8y4bYaWD;
  ControlBinop cBinop_rRqnMS1S;
  ControlVar cVar_QpAM4GsI;
  ControlVar cVar_quelAiIa;
  ControlVar cVar_AklzI4FE;
  ControlBinop cBinop_cCtQZyZV;
  ControlBinop cBinop_nrNTwTYx;
  ControlBinop cBinop_Kh1Sw6Q4;
  ControlBinop cBinop_0tmO8yHj;
  ControlBinop cBinop_1uj6xGl6;
  ControlBinop cBinop_7sSEALeJ;
  ControlBinop cBinop_EYfmDCKx;
  ControlBinop cBinop_YZuxdx4e;
  ControlBinop cBinop_1q0KI9DT;
  ControlBinop cBinop_tZrep4g2;
  ControlBinop cBinop_nCXCPpLo;
  ControlBinop cBinop_6789kCV4;
  SignalVarf sVarf_zDlEnLIJ;
  SignalVarf sVarf_iaclqBH2;
  SignalVarf sVarf_XM2d77zl;
  ControlSlice cSlice_TUC8Ge9C;
  ControlVar cVar_MLmOMhgH;
  ControlVar cVar_jI2Bt3XH;
  ControlIf cIf_kve66j0F;
  ControlIf cIf_OX4r5wis;
  ControlBinop cBinop_9Bh45aOa;
  ControlBinop cBinop_YpOkQ4Aa;
  ControlBinop cBinop_Gj6hG2H5;
  ControlBinop cBinop_ha1zXYti;
  ControlBinop cBinop_BKZn3vrf;
  ControlIf cIf_98gulf6V;
  ControlBinop cBinop_xf1SwPcH;
  ControlBinop cBinop_rQpFKBjQ;
  ControlBinop cBinop_L6LzrufE;
  ControlBinop cBinop_cabxLXcC;
  ControlBinop cBinop_bdCjf0Gz;
  ControlVar cVar_aGndHXoQ;
  ControlIf cIf_5PcPvaNu;
  ControlIf cIf_dt3AIHDf;
  ControlBinop cBinop_4xb8GILO;
  ControlBinop cBinop_KHmiSTP2;
  ControlBinop cBinop_iHdbMRf2;
  ControlBinop cBinop_2wkAxd9l;
  ControlBinop cBinop_KrGpEpyr;
  ControlIf cIf_gSCdCBow;
  ControlBinop cBinop_9DnhkZ8J;
  ControlBinop cBinop_J0E098Ih;
  ControlBinop cBinop_wPyNHSWN;
  ControlBinop cBinop_MbYwRA0C;
  ControlBinop cBinop_tGq437s7;
  ControlVar cVar_5tLA1A91;
  ControlIf cIf_qyz6vB9p;
  ControlIf cIf_aHZbj0Q8;
  ControlBinop cBinop_qavozisU;
  ControlBinop cBinop_cwc2ud88;
  ControlBinop cBinop_J5CGRC0p;
  ControlBinop cBinop_H4Bn85n5;
  ControlBinop cBinop_IDyp7lAz;
  ControlIf cIf_O7SaV4I2;
  ControlBinop cBinop_duSwgZXL;
  ControlBinop cBinop_kecqOJZ6;
  ControlBinop cBinop_TNLAIjXa;
  ControlBinop cBinop_XXvmuJRk;
  ControlBinop cBinop_bBydKueh;
  ControlIf cIf_ECzuJvZC;
  ControlSlice cSlice_4XkxXTw2;
  ControlVar cVar_hckobwao;
  ControlSlice cSlice_ky4kLRaG;
  ControlVar cVar_tCftTaoj;
  ControlSlice cSlice_aIESo4OP;
  ControlVar cVar_wipCLO1P;
  ControlSlice cSlice_keJn3jpK;
  ControlVar cVar_Y3qigsJd;
  ControlBinop cBinop_utP868Az;
  ControlBinop cBinop_rwpUd3Zd;
  ControlBinop cBinop_jauKMDZm;
  ControlBinop cBinop_mlnqTgNm;
  ControlBinop cBinop_POSlBOmj;
  ControlBinop cBinop_QPGZlUw8;
  ControlBinop cBinop_1KMi0gbV;
  ControlBinop cBinop_a8uolj6C;
  ControlVar cVar_JdvZUWg2;
  ControlBinop cBinop_6Hc2YN7k;
  ControlBinop cBinop_LRwFRjTn;
  ControlBinop cBinop_30hwd60o;
  ControlBinop cBinop_h02rU6dE;
  ControlBinop cBinop_HMwpzzRg;
  ControlBinop cBinop_t0qKIjxx;
  ControlBinop cBinop_6LFYHMhs;
  ControlBinop cBinop_gJczXXZ9;
  ControlVar cVar_H5qZ6lMC;
  ControlVar cVar_fT7z9UJ3;
  ControlBinop cBinop_OdOirFN0;
  ControlBinop cBinop_LUuCuSfl;
  ControlBinop cBinop_UZMvgmW1;
  ControlBinop cBinop_0jMbNmjg;
  ControlBinop cBinop_2A5Eij0Y;
  ControlBinop cBinop_XS98BV6A;
  ControlBinop cBinop_WZZvItAi;
  ControlBinop cBinop_kUw0IQKb;
  ControlBinop cBinop_e58iXSbA;
  ControlBinop cBinop_up0LDWes;
  ControlBinop cBinop_9GGD1mRS;
  ControlBinop cBinop_MeHYnA4b;
  ControlBinop cBinop_Ao7EOnhj;
  ControlBinop cBinop_CimvbX5i;
  ControlBinop cBinop_pz37P1l0;
  ControlBinop cBinop_hCj2HJ77;
  ControlBinop cBinop_pxzT2AiT;
  ControlBinop cBinop_fLo6Pr0Q;
  ControlBinop cBinop_5jl0lw4A;
  ControlBinop cBinop_VuZG26U0;
  ControlVar cVar_UtdxR2jt;
  ControlVar cVar_dmHTAZx9;
  ControlVar cVar_GuzmVPNU;
  ControlBinop cBinop_Rx5xBBnW;
  ControlBinop cBinop_6usUjnpT;
  ControlBinop cBinop_ZovJl7xW;
  ControlBinop cBinop_zH54a3uS;
  ControlBinop cBinop_QJcQHYL0;
  ControlBinop cBinop_3LtrYC24;
  ControlBinop cBinop_92Ktd29H;
  ControlBinop cBinop_s00l4tke;
  ControlBinop cBinop_XrA2LFa9;
  ControlBinop cBinop_BAA2LSoN;
  ControlBinop cBinop_SDbyB1r7;
  ControlBinop cBinop_lqEpwUqb;
  ControlBinop cBinop_Rzy3WLti;
  ControlBinop cBinop_3d9v9Xcb;
  ControlBinop cBinop_MTymP76J;
  ControlBinop cBinop_YibmEURJ;
  ControlBinop cBinop_0p5JVyRR;
  ControlBinop cBinop_gRZ2BypM;
  ControlBinop cBinop_Mi4B3S4i;
  ControlBinop cBinop_dddBDJHg;
  ControlBinop cBinop_xdplpNl8;
  ControlBinop cBinop_qpj4gnNU;
  ControlBinop cBinop_QZgTraHk;
  ControlVar cVar_EszGlR5I;
  ControlVar cVar_zXGqFjQN;
  ControlVar cVar_dHeJODCz;
  ControlBinop cBinop_EvD5o6Aa;
  ControlBinop cBinop_PSUooRHR;
  ControlBinop cBinop_m8RCg67c;
  ControlBinop cBinop_0SdNVL14;
  ControlBinop cBinop_GIEyP9B0;
  ControlBinop cBinop_wl20k4VL;
  ControlBinop cBinop_NKaK6w32;
  ControlBinop cBinop_uHGc1W7B;
  ControlBinop cBinop_sa0r9GBI;
  ControlBinop cBinop_TIXPuhze;
  ControlBinop cBinop_htdLHSqO;
  ControlBinop cBinop_qzwrMRS0;
  SignalVarf sVarf_JBiaEqTC;
  SignalVarf sVarf_BrIn9K3S;
  SignalVarf sVarf_3ZPAmZ0Q;
  ControlVar cVar_MJ7bsSBf;
  ControlVar cVar_S3cMBvEj;
  ControlBinop cBinop_MGULSpPX;
  ControlBinop cBinop_xFUbW4WF;
  ControlBinop cBinop_pOlNGK8i;
  ControlBinop cBinop_QJeUcO1K;
  ControlBinop cBinop_G4NWpP1c;
  ControlBinop cBinop_3whfl2k6;
  ControlBinop cBinop_r5OCWNu3;
};

#endif // _HEAVY_CONTEXT_WSTD_3Q_HPP_
