/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_3Q.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_3Q *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_3Q_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_3Q();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_3Q::Heavy_WSTD_3Q(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_juIJ1bq3);
  numBytes += sLine_init(&sLine_HSBlfto4);
  numBytes += sLine_init(&sLine_k3cMVEUZ);
  numBytes += sLine_init(&sLine_mC5qFVyT);
  numBytes += sLine_init(&sLine_zxaTfkul);
  numBytes += sBiquad_init(&sBiquad_s_FaEjAeYp);
  numBytes += sLine_init(&sLine_5UTUSTPe);
  numBytes += sLine_init(&sLine_0dv8q0TN);
  numBytes += sLine_init(&sLine_10gBQTkR);
  numBytes += sLine_init(&sLine_A0WDN8Yk);
  numBytes += sBiquad_init(&sBiquad_s_GejiYPJV);
  numBytes += sLine_init(&sLine_2kjBMG0s);
  numBytes += sLine_init(&sLine_J1GxVKre);
  numBytes += sLine_init(&sLine_NtFUxcRi);
  numBytes += sLine_init(&sLine_zKKNZFmj);
  numBytes += sLine_init(&sLine_oEfaW6mc);
  numBytes += sBiquad_init(&sBiquad_s_uMocLMLe);
  numBytes += sLine_init(&sLine_I7hwoE8y);
  numBytes += sLine_init(&sLine_w0Pwbzkq);
  numBytes += sLine_init(&sLine_jwODPWiI);
  numBytes += sLine_init(&sLine_Gt25HlmX);
  numBytes += sLine_init(&sLine_26lIDdD7);
  numBytes += sBiquad_init(&sBiquad_s_76qvNynj);
  numBytes += sLine_init(&sLine_rAIke8YP);
  numBytes += sLine_init(&sLine_NmFyk9xE);
  numBytes += sLine_init(&sLine_SGLRmN8v);
  numBytes += sLine_init(&sLine_0ndUEwve);
  numBytes += sBiquad_init(&sBiquad_s_4EkTAIb9);
  numBytes += sLine_init(&sLine_iYK0Mw9A);
  numBytes += sLine_init(&sLine_ie1TZBzw);
  numBytes += sLine_init(&sLine_Z3vvWvgs);
  numBytes += sLine_init(&sLine_CcnaJ4Ex);
  numBytes += sLine_init(&sLine_L7tnfZDQ);
  numBytes += sBiquad_init(&sBiquad_s_awTxZnc4);
  numBytes += cVar_init_f(&cVar_35jiVoDp, 0.0f);
  numBytes += cVar_init_f(&cVar_rTaQUM2Y, 0.0f);
  numBytes += cVar_init_f(&cVar_2J2YYuHz, 0.0f);
  numBytes += cVar_init_f(&cVar_FgWI582P, 0.0f);
  numBytes += cSlice_init(&cSlice_J7c8s9rL, 1, -1);
  numBytes += cVar_init_f(&cVar_CwAX2thZ, 1337.0f);
  numBytes += cVar_init_f(&cVar_lLOD0VAU, 0.0f);
  numBytes += cIf_init(&cIf_pHbgFsPB, false);
  numBytes += cIf_init(&cIf_TU9kde7j, false);
  numBytes += cBinop_init(&cBinop_h1y2Rpdt, 0.0f); // __pow
  numBytes += cIf_init(&cIf_OXh4huGs, false);
  numBytes += cBinop_init(&cBinop_vAziwhJp, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_4jWHMlR4, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_jeZ2zFR3, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_RZyVcJhy, 0.0f);
  numBytes += cIf_init(&cIf_abY7qaXo, false);
  numBytes += cIf_init(&cIf_No7WwuUP, false);
  numBytes += cBinop_init(&cBinop_Kch4erE6, 0.0f); // __pow
  numBytes += cIf_init(&cIf_aHCI6pMj, false);
  numBytes += cBinop_init(&cBinop_9mlsy2dH, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_OeFF2vJv, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_UgFWtodM, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_vcDBbsZw, 0.0f);
  numBytes += cIf_init(&cIf_gFtckCRE, false);
  numBytes += cIf_init(&cIf_U9Taqq2Q, false);
  numBytes += cBinop_init(&cBinop_y4AxY5RG, 0.0f); // __pow
  numBytes += cIf_init(&cIf_JJZzpyLg, false);
  numBytes += cBinop_init(&cBinop_wt9fOPm7, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_0oZ2M6In, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_szEfeUmh, -15.0f); // __eq
  numBytes += cIf_init(&cIf_888QLQfq, false);
  numBytes += cSlice_init(&cSlice_43PBrehv, 1, -1);
  numBytes += cVar_init_f(&cVar_ZOsv9dwg, 0.0f);
  numBytes += cSlice_init(&cSlice_dRKGtAGs, 1, -1);
  numBytes += cVar_init_f(&cVar_pCEforIK, 0.0f);
  numBytes += cSlice_init(&cSlice_AVk4fVAJ, 1, -1);
  numBytes += cVar_init_f(&cVar_vzmfNFSc, 0.0f);
  numBytes += cSlice_init(&cSlice_vnqn0UWw, 1, -1);
  numBytes += cVar_init_f(&cVar_hUBZz1FT, 0.313f);
  numBytes += cBinop_init(&cBinop_83YzsKOv, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_4b2b7bh2, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_iHnWkYA9, 0.0f);
  numBytes += cVar_init_f(&cVar_uBdm1D1T, 1337.0f);
  numBytes += cVar_init_f(&cVar_e4WfEkvJ, 0.3f);
  numBytes += cBinop_init(&cBinop_CQ24WrF3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZZdCMTjf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LZRbxp0z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_W0O5hpXc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_T92cnXzS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8lCcjCmR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SsyP4nZR, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_RpAYCLZA, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_cqm8FLke, 0.0f);
  numBytes += cVar_init_f(&cVar_L80f7Lq4, 1337.0f);
  numBytes += cVar_init_f(&cVar_FpSRxUO0, 0.313f);
  numBytes += cBinop_init(&cBinop_b9uvRujC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aNNg9LQd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sE6jQBGQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_f3TAmgja, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_u37EFmAH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_t134N6QK, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_3WV3VUhD, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_QpAM4GsI, 0.0f);
  numBytes += cVar_init_f(&cVar_quelAiIa, 1037.0f);
  numBytes += cVar_init_f(&cVar_AklzI4FE, 0.4f);
  numBytes += cBinop_init(&cBinop_nrNTwTYx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1uj6xGl6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7sSEALeJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EYfmDCKx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YZuxdx4e, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1q0KI9DT, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_zDlEnLIJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iaclqBH2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XM2d77zl, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_TUC8Ge9C, 1, -1);
  numBytes += cVar_init_f(&cVar_MLmOMhgH, 1337.0f);
  numBytes += cVar_init_f(&cVar_jI2Bt3XH, 0.0f);
  numBytes += cIf_init(&cIf_kve66j0F, false);
  numBytes += cIf_init(&cIf_OX4r5wis, false);
  numBytes += cBinop_init(&cBinop_9Bh45aOa, 0.0f); // __pow
  numBytes += cIf_init(&cIf_98gulf6V, false);
  numBytes += cBinop_init(&cBinop_L6LzrufE, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_cabxLXcC, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_bdCjf0Gz, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_aGndHXoQ, 0.0f);
  numBytes += cIf_init(&cIf_5PcPvaNu, false);
  numBytes += cIf_init(&cIf_dt3AIHDf, false);
  numBytes += cBinop_init(&cBinop_4xb8GILO, 0.0f); // __pow
  numBytes += cIf_init(&cIf_gSCdCBow, false);
  numBytes += cBinop_init(&cBinop_wPyNHSWN, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_MbYwRA0C, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_tGq437s7, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_5tLA1A91, 0.0f);
  numBytes += cIf_init(&cIf_qyz6vB9p, false);
  numBytes += cIf_init(&cIf_aHZbj0Q8, false);
  numBytes += cBinop_init(&cBinop_qavozisU, 0.0f); // __pow
  numBytes += cIf_init(&cIf_O7SaV4I2, false);
  numBytes += cBinop_init(&cBinop_TNLAIjXa, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_XXvmuJRk, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_bBydKueh, -15.0f); // __eq
  numBytes += cIf_init(&cIf_ECzuJvZC, false);
  numBytes += cSlice_init(&cSlice_4XkxXTw2, 1, -1);
  numBytes += cVar_init_f(&cVar_hckobwao, 0.0f);
  numBytes += cSlice_init(&cSlice_ky4kLRaG, 1, -1);
  numBytes += cVar_init_f(&cVar_tCftTaoj, 0.0f);
  numBytes += cSlice_init(&cSlice_aIESo4OP, 1, -1);
  numBytes += cVar_init_f(&cVar_wipCLO1P, 0.0f);
  numBytes += cSlice_init(&cSlice_keJn3jpK, 1, -1);
  numBytes += cVar_init_f(&cVar_Y3qigsJd, 0.313f);
  numBytes += cBinop_init(&cBinop_rwpUd3Zd, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_jauKMDZm, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_JdvZUWg2, 0.0f);
  numBytes += cVar_init_f(&cVar_H5qZ6lMC, 1337.0f);
  numBytes += cVar_init_f(&cVar_fT7z9UJ3, 0.3f);
  numBytes += cBinop_init(&cBinop_LUuCuSfl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2A5Eij0Y, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XS98BV6A, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WZZvItAi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kUw0IQKb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_e58iXSbA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9GGD1mRS, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_MeHYnA4b, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_UtdxR2jt, 0.0f);
  numBytes += cVar_init_f(&cVar_dmHTAZx9, 1337.0f);
  numBytes += cVar_init_f(&cVar_GuzmVPNU, 0.313f);
  numBytes += cBinop_init(&cBinop_6usUjnpT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QJcQHYL0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3LtrYC24, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_92Ktd29H, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_s00l4tke, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BAA2LSoN, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_SDbyB1r7, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_EszGlR5I, 0.0f);
  numBytes += cVar_init_f(&cVar_zXGqFjQN, 1037.0f);
  numBytes += cVar_init_f(&cVar_dHeJODCz, 0.4f);
  numBytes += cBinop_init(&cBinop_PSUooRHR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GIEyP9B0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wl20k4VL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NKaK6w32, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uHGc1W7B, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sa0r9GBI, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_JBiaEqTC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BrIn9K3S, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3ZPAmZ0Q, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_MJ7bsSBf, 5705.6f);
  numBytes += cVar_init_f(&cVar_S3cMBvEj, 313.3f);
  numBytes += cBinop_init(&cBinop_MGULSpPX, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_xFUbW4WF, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_pOlNGK8i, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_3Q::~Heavy_WSTD_3Q() {
  // nothing to free
}

HvTable *Heavy_WSTD_3Q::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_3Q::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IX3jnT5A_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RcxbrAD1_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kfGaRJdd_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PlVTtVTF_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_quTNmeA1_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1S9gv0Jq_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eXrOYwB8_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1oN7x6HA_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VBnv8PAd_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zQsbEgWC_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZBjtXVW4_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MaIm6KIq_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6itgj6Wy_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DLogvRyd_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lE7jqGYa_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NLZb45dK_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8XHo6kNt_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TyfvJGza_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pDWYruV5_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7yJL9a4z_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sJT1hcyi_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_67HGSACL_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Z8mez8Mb_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3If2TjRj_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GLOjtTGu_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rRdPSd2h_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SNX3asYW_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1LB4kwFw_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hMa4mTR2_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Se0RsNFt_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ABNeBZCK_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xYjD0iqC_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PCfeeOoa_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_3Q::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_3Q::cVar_35jiVoDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3QKzTCq8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_rTaQUM2Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qFHsjrrQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_2J2YYuHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KgAXFtJV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_FgWI582P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uAqeWiu1_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rd4Sbo0R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VXnQcPeH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n5XxC71M_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_hGXWousQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_J7c8s9rL, 0, m, &cSlice_J7c8s9rL_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7XnTHPWb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_J7c8s9rL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_1NLGWZV7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_1NLGWZV7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_CwAX2thZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1NLGWZV7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_1NLGWZV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eXrOYwB8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_lLOD0VAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ytl09HDO_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_pHbgFsPB, 0, m, &cIf_pHbgFsPB_sendMessage);
}

void Heavy_WSTD_3Q::cIf_pHbgFsPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_QH1EHqkG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_TU9kde7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_mvhSTzCi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_uBwbRacQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_7rM6cmbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_h1y2Rpdt, HV_BINOP_POW, 0, m, &cBinop_h1y2Rpdt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_h1y2Rpdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OXh4huGs, 0, m, &cIf_OXh4huGs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_czFTbuFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ZFOyCWsJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_aeBJ3mKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CaNenXIl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_YG7To4RO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TU9kde7j, 0, m, &cIf_TU9kde7j_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CaNenXIl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TU9kde7j, 1, m, &cIf_TU9kde7j_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uBwbRacQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_czFTbuFi_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_mvhSTzCi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_OXh4huGs, 0, m, &cIf_OXh4huGs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZFOyCWsJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h1y2Rpdt, HV_BINOP_POW, 1, m, &cBinop_h1y2Rpdt_sendMessage);
  cMsg_7rM6cmbq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_OXh4huGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_zDlEnLIJ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_ytl09HDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pHbgFsPB, 1, m, &cIf_pHbgFsPB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QH1EHqkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4jWHMlR4, HV_BINOP_GREATER_THAN, 1, m, &cBinop_4jWHMlR4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jeZ2zFR3, HV_BINOP_EQ, 1, m, &cBinop_jeZ2zFR3_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_31IhSCFo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vAziwhJp, HV_BINOP_ADD, 0, m, &cBinop_vAziwhJp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vAziwhJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aeBJ3mKI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YG7To4RO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4jWHMlR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OXh4huGs, 1, m, &cIf_OXh4huGs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jeZ2zFR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_USEEBLI8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_USEEBLI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_zDlEnLIJ, m);
}

void Heavy_WSTD_3Q::cCast_wIfUkiTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vAziwhJp, HV_BINOP_ADD, 1, m, &cBinop_vAziwhJp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4jWHMlR4, HV_BINOP_GREATER_THAN, 0, m, &cBinop_4jWHMlR4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jeZ2zFR3, HV_BINOP_EQ, 0, m, &cBinop_jeZ2zFR3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KJWBaAm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_31IhSCFo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_YCDxk4jP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lLOD0VAU, 0, m, &cVar_lLOD0VAU_sendMessage);
}

void Heavy_WSTD_3Q::cVar_RZyVcJhy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pI5xzTa5_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_abY7qaXo, 0, m, &cIf_abY7qaXo_sendMessage);
}

void Heavy_WSTD_3Q::cIf_abY7qaXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kxlTuy3X_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_No7WwuUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_hEzpGjOQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_XRyhNvcP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_MMQSgkIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kch4erE6, HV_BINOP_POW, 0, m, &cBinop_Kch4erE6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Kch4erE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aHCI6pMj, 0, m, &cIf_aHCI6pMj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NfTCUW1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_X1inKnCT_sendMessage);
}

void Heavy_WSTD_3Q::cCast_avu6uxI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_No7WwuUP, 0, m, &cIf_No7WwuUP_sendMessage);
}

void Heavy_WSTD_3Q::cCast_wgLHJzLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CZD55N3j_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CZD55N3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_No7WwuUP, 1, m, &cIf_No7WwuUP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XRyhNvcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_NfTCUW1l_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_hEzpGjOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_aHCI6pMj, 0, m, &cIf_aHCI6pMj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_X1inKnCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kch4erE6, HV_BINOP_POW, 1, m, &cBinop_Kch4erE6_sendMessage);
  cMsg_MMQSgkIc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_aHCI6pMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_tZrep4g2_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nCXCPpLo_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_6789kCV4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_pI5xzTa5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_abY7qaXo, 1, m, &cIf_abY7qaXo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kxlTuy3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OeFF2vJv, HV_BINOP_GREATER_THAN, 1, m, &cBinop_OeFF2vJv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UgFWtodM, HV_BINOP_EQ, 1, m, &cBinop_UgFWtodM_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_SpNT3PPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9mlsy2dH, HV_BINOP_ADD, 0, m, &cBinop_9mlsy2dH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9mlsy2dH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wgLHJzLO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_avu6uxI1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OeFF2vJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aHCI6pMj, 1, m, &cIf_aHCI6pMj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UgFWtodM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xaNEvmAe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_xaNEvmAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_tZrep4g2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nCXCPpLo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_6789kCV4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_IPGzfuuf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SpNT3PPe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_A23e1Wt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9mlsy2dH, HV_BINOP_ADD, 1, m, &cBinop_9mlsy2dH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OeFF2vJv, HV_BINOP_GREATER_THAN, 0, m, &cBinop_OeFF2vJv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UgFWtodM, HV_BINOP_EQ, 0, m, &cBinop_UgFWtodM_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TE0hWuFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RZyVcJhy, 0, m, &cVar_RZyVcJhy_sendMessage);
}

void Heavy_WSTD_3Q::cVar_vcDBbsZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KdnLkrGz_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_gFtckCRE, 0, m, &cIf_gFtckCRE_sendMessage);
}

void Heavy_WSTD_3Q::cIf_gFtckCRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xiNaaaJs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_U9Taqq2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ZSIpY4n2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_MXKXLBE5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_hruw8TQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_y4AxY5RG, HV_BINOP_POW, 0, m, &cBinop_y4AxY5RG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_y4AxY5RG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JJZzpyLg, 0, m, &cIf_JJZzpyLg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YgDfqec2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_rgbVcEgF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QJwUQev1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ra84uwbt_sendMessage);
}

void Heavy_WSTD_3Q::cCast_oCyEnA0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U9Taqq2Q, 0, m, &cIf_U9Taqq2Q_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ra84uwbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U9Taqq2Q, 1, m, &cIf_U9Taqq2Q_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MXKXLBE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_YgDfqec2_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ZSIpY4n2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_JJZzpyLg, 0, m, &cIf_JJZzpyLg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rgbVcEgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y4AxY5RG, HV_BINOP_POW, 1, m, &cBinop_y4AxY5RG_sendMessage);
  cMsg_hruw8TQ5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_JJZzpyLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_XM2d77zl, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_KdnLkrGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gFtckCRE, 1, m, &cIf_gFtckCRE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xiNaaaJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0oZ2M6In, HV_BINOP_GREATER_THAN, 1, m, &cBinop_0oZ2M6In_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_szEfeUmh, HV_BINOP_EQ, 1, m, &cBinop_szEfeUmh_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_nW5TwM80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wt9fOPm7, HV_BINOP_ADD, 0, m, &cBinop_wt9fOPm7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wt9fOPm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QJwUQev1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oCyEnA0a_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0oZ2M6In_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JJZzpyLg, 1, m, &cIf_JJZzpyLg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_szEfeUmh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3ulf4ZQS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_3ulf4ZQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_XM2d77zl, m);
}

void Heavy_WSTD_3Q::cCast_NMyt1sMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nW5TwM80_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_b7id82Qe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wt9fOPm7, HV_BINOP_ADD, 1, m, &cBinop_wt9fOPm7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0oZ2M6In, HV_BINOP_GREATER_THAN, 0, m, &cBinop_0oZ2M6In_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_szEfeUmh, HV_BINOP_EQ, 0, m, &cBinop_szEfeUmh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_cjoJNF8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vcDBbsZw, 0, m, &cVar_vcDBbsZw_sendMessage);
}

void Heavy_WSTD_3Q::cIf_888QLQfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_iaclqBH2, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_13Goj8qS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_43PBrehv, 0, m, &cSlice_43PBrehv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NPWlq3bG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_43PBrehv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gJqQFZ0k_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gJqQFZ0k_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_ZOsv9dwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gJqQFZ0k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_gJqQFZ0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_quTNmeA1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_NPWlq3bG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dRKGtAGs, 0, m, &cSlice_dRKGtAGs_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hGXWousQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_dRKGtAGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QZ8zZwaI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QZ8zZwaI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_pCEforIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QZ8zZwaI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_QZ8zZwaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VBnv8PAd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_7XnTHPWb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AVk4fVAJ, 0, m, &cSlice_AVk4fVAJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5OrLqyVK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_AVk4fVAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xcjfsnJO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xcjfsnJO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_vzmfNFSc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xcjfsnJO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_xcjfsnJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1S9gv0Jq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_5OrLqyVK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vnqn0UWw, 0, m, &cSlice_vnqn0UWw_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_vnqn0UWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9Ymip5dv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9Ymip5dv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_hUBZz1FT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9Ymip5dv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_9Ymip5dv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1oN7x6HA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_io8tlb5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_juIJ1bq3, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_c2e7UUSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HSBlfto4, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_EYwk0gy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_k3cMVEUZ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_GyCK9FI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mC5qFVyT, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_j0f3zDRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zxaTfkul, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_b0Zp1n3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gM4x3jIP_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_gM4x3jIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_83YzsKOv, HV_BINOP_DIVIDE, 1, m, &cBinop_83YzsKOv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5whiZkKI_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_LWyGyQFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_9vvVBRCd_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_5BJJbojh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_LWyGyQFj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9vvVBRCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_83YzsKOv, HV_BINOP_DIVIDE, 0, m, &cBinop_83YzsKOv_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5whiZkKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5BJJbojh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_83YzsKOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4b2b7bh2, HV_BINOP_MULTIPLY, 1, m, &cBinop_4b2b7bh2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4b2b7bh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zp78cBLe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H7qmrniN_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_GzAOudKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Vb9dLI7G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_KIaBe7tR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4RAKP9sB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_C7tbjDbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_5AYpUKni_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5AYpUKni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4b2b7bh2, HV_BINOP_MULTIPLY, 0, m, &cBinop_4b2b7bh2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Al6j2xqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_HlLPy2Tz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HlLPy2Tz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fHM5YKVR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_jrxJcsfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iHnWkYA9, 1, m, &cVar_iHnWkYA9_sendMessage);
}

void Heavy_WSTD_3Q::cVar_iHnWkYA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xWslxNuI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_XLZ1o6aJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZZdCMTjf, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZZdCMTjf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qaFOePTO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_XLZ1o6aJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LtMyUSOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_518fNBl4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_518fNBl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LZRbxp0z, HV_BINOP_MULTIPLY, 1, m, &cBinop_LZRbxp0z_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rRmhCvQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W0O5hpXc, HV_BINOP_MULTIPLY, 1, m, &cBinop_W0O5hpXc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_M13O2YrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rRmhCvQ8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PSiPnIeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T92cnXzS, HV_BINOP_MULTIPLY, 1, m, &cBinop_T92cnXzS_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_PHRvcuge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_iPW2MaEX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iPW2MaEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8lCcjCmR, HV_BINOP_MULTIPLY, 1, m, &cBinop_8lCcjCmR_sendMessage);
}

void Heavy_WSTD_3Q::cVar_uBdm1D1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vRkioUL2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_C7tbjDbl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HdsJcuPc_sendMessage);
}

void Heavy_WSTD_3Q::cVar_e4WfEkvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Al6j2xqz_sendMessage);
}

void Heavy_WSTD_3Q::cCast_H7qmrniN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_KIaBe7tR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zp78cBLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_GzAOudKK_sendMessage);
}

void Heavy_WSTD_3Q::cSend_Vb9dLI7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MaIm6KIq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_4RAKP9sB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZBjtXVW4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_WjDPkoLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zQsbEgWC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_fHM5YKVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_DOCJ21uk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DOCJ21uk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CQ24WrF3, HV_BINOP_MULTIPLY, 1, m, &cBinop_CQ24WrF3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CQ24WrF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jV7IUaWP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jV7IUaWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WjDPkoLt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_xWslxNuI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_shGjF842_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_shGjF842_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sfM09w6m_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4KjaNM2G_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5p2P0uSm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0SGP9kfz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3kygDY0t_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MmRmkjBr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZZdCMTjf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_io8tlb5f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_LZRbxp0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c2e7UUSK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_W0O5hpXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EYwk0gy9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_T92cnXzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GyCK9FI4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_8lCcjCmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j0f3zDRR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_zP8UIOPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uBdm1D1T, 0, m, &cVar_uBdm1D1T_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Mu78kELg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e4WfEkvJ, 1, m, &cVar_e4WfEkvJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MmRmkjBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZZdCMTjf, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZZdCMTjf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_sfM09w6m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_0SGP9kfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W0O5hpXc, HV_BINOP_MULTIPLY, 0, m, &cBinop_W0O5hpXc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5p2P0uSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T92cnXzS, HV_BINOP_MULTIPLY, 0, m, &cBinop_T92cnXzS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3kygDY0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LZRbxp0z, HV_BINOP_MULTIPLY, 0, m, &cBinop_LZRbxp0z_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4KjaNM2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8lCcjCmR, HV_BINOP_MULTIPLY, 0, m, &cBinop_8lCcjCmR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HdsJcuPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iHnWkYA9, 0, m, &cVar_iHnWkYA9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vRkioUL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e4WfEkvJ, 0, m, &cVar_e4WfEkvJ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_rZ4akLMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5UTUSTPe, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_0xIXOSZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0dv8q0TN, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_NlqVGD6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_10gBQTkR, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_vuaZMRae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_A0WDN8Yk, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_0PnzQOq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2TM0gO9o_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_2TM0gO9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SsyP4nZR, HV_BINOP_DIVIDE, 1, m, &cBinop_SsyP4nZR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VFedBJq3_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_CdGeV0FV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_pN5OX3ji_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_KRtyns0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_CdGeV0FV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pN5OX3ji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SsyP4nZR, HV_BINOP_DIVIDE, 0, m, &cBinop_SsyP4nZR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VFedBJq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KRtyns0a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_SsyP4nZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RpAYCLZA, HV_BINOP_MULTIPLY, 1, m, &cBinop_RpAYCLZA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RpAYCLZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bk2eYhHE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9jXD3u0S_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_uJ8BSCsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xuUm0qc6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_a8k9iDL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7ackFWCU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_lQXBqGPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_9XMWOlRk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9XMWOlRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RpAYCLZA, HV_BINOP_MULTIPLY, 0, m, &cBinop_RpAYCLZA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_q1280NFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_eTjRUZUc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eTjRUZUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5loSGAs9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_o5NHEm4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sE6jQBGQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_sE6jQBGQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uJve27a2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cqm8FLke, 1, m, &cVar_cqm8FLke_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YvOBrzE3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f3TAmgja, HV_BINOP_MULTIPLY, 1, m, &cBinop_f3TAmgja_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_lGbQqbet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_AjRu19oh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AjRu19oh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u37EFmAH, HV_BINOP_MULTIPLY, 1, m, &cBinop_u37EFmAH_sendMessage);
}

void Heavy_WSTD_3Q::cVar_cqm8FLke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YVjmmcbD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_L80f7Lq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qE6uPMsK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_lQXBqGPA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lzD0Ztku_sendMessage);
}

void Heavy_WSTD_3Q::cVar_FpSRxUO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_q1280NFS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bk2eYhHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_uJ8BSCsC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_9jXD3u0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_a8k9iDL7_sendMessage);
}

void Heavy_WSTD_3Q::cSend_xuUm0qc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lE7jqGYa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_7ackFWCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DLogvRyd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_m7GNjEPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6itgj6Wy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_5loSGAs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7vfb4G3I_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7vfb4G3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b9uvRujC, HV_BINOP_MULTIPLY, 1, m, &cBinop_b9uvRujC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_b9uvRujC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_iDY7l7pv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iDY7l7pv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_m7GNjEPZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_YVjmmcbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5gfgqnVd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5gfgqnVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SRyD4Cae_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7tQtUAWk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NJ28XbwF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrLQSvGZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aNNg9LQd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rZ4akLMC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_sE6jQBGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0xIXOSZk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_f3TAmgja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NlqVGD6K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_u37EFmAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vuaZMRae_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_7vH5f0Ql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_L80f7Lq4, 0, m, &cVar_L80f7Lq4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_elos98Hk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FpSRxUO0, 1, m, &cVar_FpSRxUO0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qE6uPMsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FpSRxUO0, 0, m, &cVar_FpSRxUO0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lzD0Ztku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cqm8FLke, 0, m, &cVar_cqm8FLke_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7tQtUAWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f3TAmgja, HV_BINOP_MULTIPLY, 0, m, &cBinop_f3TAmgja_sendMessage);
}

void Heavy_WSTD_3Q::cCast_NJ28XbwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sE6jQBGQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_sE6jQBGQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lrLQSvGZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aNNg9LQd, HV_BINOP_MULTIPLY, 0, m, &cBinop_aNNg9LQd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_SRyD4Cae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u37EFmAH, HV_BINOP_MULTIPLY, 0, m, &cBinop_u37EFmAH_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_9P8VThHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2kjBMG0s, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_GxPvptu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J1GxVKre, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_IAxZ6KVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NtFUxcRi, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_jXYdMNiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zKKNZFmj, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_0cfSoDlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oEfaW6mc, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_GvKkYBHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UfdWFS1y_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_UfdWFS1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t134N6QK, HV_BINOP_DIVIDE, 1, m, &cBinop_t134N6QK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mChKSvu7_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_yKImrlwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_7ZCFYPAb_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_4XajmBTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_yKImrlwj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7ZCFYPAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t134N6QK, HV_BINOP_DIVIDE, 0, m, &cBinop_t134N6QK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mChKSvu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4XajmBTY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_t134N6QK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3WV3VUhD, HV_BINOP_MULTIPLY, 1, m, &cBinop_3WV3VUhD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3WV3VUhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qKYk2b7g_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2ry5Vc6i_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_n22DpZvE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_w8mvTjhw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_69h4dxby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nR9npK3e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_9fCgaz0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_ad6p63AB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ad6p63AB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3WV3VUhD, HV_BINOP_MULTIPLY, 0, m, &cBinop_3WV3VUhD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kAp2HeG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_dY7KdToX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dY7KdToX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TPbDRWcc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_QsHze980_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1uj6xGl6, HV_BINOP_MULTIPLY, 1, m, &cBinop_1uj6xGl6_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_uixrIlCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BaLz9QQJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BaLz9QQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QsHze980_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_jefOKAhh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_e3g1YtDP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_e3g1YtDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7sSEALeJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_7sSEALeJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HquFjcyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EYfmDCKx, HV_BINOP_MULTIPLY, 1, m, &cBinop_EYfmDCKx_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_tGcAKG5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_weUNpxhA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_weUNpxhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HquFjcyf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CAmzgc6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QpAM4GsI, 1, m, &cVar_QpAM4GsI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8y4bYaWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YZuxdx4e, HV_BINOP_MULTIPLY, 1, m, &cBinop_YZuxdx4e_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_r4V3CACJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rRqnMS1S_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rRqnMS1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1q0KI9DT, HV_BINOP_MULTIPLY, 1, m, &cBinop_1q0KI9DT_sendMessage);
}

void Heavy_WSTD_3Q::cVar_QpAM4GsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YkACgtMt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_quelAiIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qfkv7iRG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_9fCgaz0F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vCj5QGlE_sendMessage);
}

void Heavy_WSTD_3Q::cVar_AklzI4FE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_kAp2HeG8_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2ry5Vc6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_69h4dxby_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qKYk2b7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_n22DpZvE_sendMessage);
}

void Heavy_WSTD_3Q::cSend_w8mvTjhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TyfvJGza_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_nR9npK3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8XHo6kNt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_iJA6jmJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NLZb45dK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_TPbDRWcc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_cCtQZyZV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cCtQZyZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nrNTwTYx, HV_BINOP_MULTIPLY, 1, m, &cBinop_nrNTwTYx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nrNTwTYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Kh1Sw6Q4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Kh1Sw6Q4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iJA6jmJm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_YkACgtMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0tmO8yHj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0tmO8yHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kbc2ANef_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CN1S1Npi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HwSzn43w_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a7Y3ZRz0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GaE2EWLD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a0f17LBD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1uj6xGl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9P8VThHD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_7sSEALeJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GxPvptu2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_EYfmDCKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IAxZ6KVQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_YZuxdx4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jXYdMNiB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_1q0KI9DT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0cfSoDlm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_8v1go96R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_quelAiIa, 0, m, &cVar_quelAiIa_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8NUsWozA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AklzI4FE, 1, m, &cVar_AklzI4FE_sendMessage);
}

void Heavy_WSTD_3Q::cCast_a7Y3ZRz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EYfmDCKx, HV_BINOP_MULTIPLY, 0, m, &cBinop_EYfmDCKx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_CN1S1Npi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1q0KI9DT, HV_BINOP_MULTIPLY, 0, m, &cBinop_1q0KI9DT_sendMessage);
}

void Heavy_WSTD_3Q::cCast_a0f17LBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1uj6xGl6, HV_BINOP_MULTIPLY, 0, m, &cBinop_1uj6xGl6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_kbc2ANef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_GaE2EWLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7sSEALeJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_7sSEALeJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HwSzn43w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YZuxdx4e, HV_BINOP_MULTIPLY, 0, m, &cBinop_YZuxdx4e_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vCj5QGlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QpAM4GsI, 0, m, &cVar_QpAM4GsI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Qfkv7iRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AklzI4FE, 0, m, &cVar_AklzI4FE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tZrep4g2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_888QLQfq, 1, m, &cIf_888QLQfq_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_vQgfWTP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_iaclqBH2, m);
}

void Heavy_WSTD_3Q::cBinop_nCXCPpLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vQgfWTP3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_6789kCV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_888QLQfq, 0, m, &cIf_888QLQfq_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_rtRHGwhU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TUC8Ge9C, 0, m, &cSlice_TUC8Ge9C_sendMessage);
      break;
    }
    default: {
      cSwitchcase_c0EOQrN2_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_TUC8Ge9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qv4rmsVh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qv4rmsVh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_MLmOMhgH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qv4rmsVh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_qv4rmsVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sJT1hcyi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_jI2Bt3XH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xf1SwPcH_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_kve66j0F, 0, m, &cIf_kve66j0F_sendMessage);
}

void Heavy_WSTD_3Q::cIf_kve66j0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_rQpFKBjQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_OX4r5wis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_lpTJ77zX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ha1zXYti_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_f3Ia2pui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9Bh45aOa, HV_BINOP_POW, 0, m, &cBinop_9Bh45aOa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9Bh45aOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_98gulf6V, 0, m, &cIf_98gulf6V_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YpOkQ4Aa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_BKZn3vrf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lKd2iibL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Gj6hG2H5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xj8BsByx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OX4r5wis, 0, m, &cIf_OX4r5wis_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Gj6hG2H5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OX4r5wis, 1, m, &cIf_OX4r5wis_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ha1zXYti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_YpOkQ4Aa_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_lpTJ77zX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_98gulf6V, 0, m, &cIf_98gulf6V_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BKZn3vrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9Bh45aOa, HV_BINOP_POW, 1, m, &cBinop_9Bh45aOa_sendMessage);
  cMsg_f3Ia2pui_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_98gulf6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_JBiaEqTC, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_xf1SwPcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kve66j0F, 1, m, &cIf_kve66j0F_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rQpFKBjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cabxLXcC, HV_BINOP_GREATER_THAN, 1, m, &cBinop_cabxLXcC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bdCjf0Gz, HV_BINOP_EQ, 1, m, &cBinop_bdCjf0Gz_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_85AICjYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_L6LzrufE, HV_BINOP_ADD, 0, m, &cBinop_L6LzrufE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_L6LzrufE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lKd2iibL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xj8BsByx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cabxLXcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_98gulf6V, 1, m, &cIf_98gulf6V_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bdCjf0Gz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_biel8HZa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_biel8HZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_JBiaEqTC, m);
}

void Heavy_WSTD_3Q::cCast_bpcFiTHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jI2Bt3XH, 0, m, &cVar_jI2Bt3XH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_apB8sDeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L6LzrufE, HV_BINOP_ADD, 1, m, &cBinop_L6LzrufE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cabxLXcC, HV_BINOP_GREATER_THAN, 0, m, &cBinop_cabxLXcC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bdCjf0Gz, HV_BINOP_EQ, 0, m, &cBinop_bdCjf0Gz_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0K1iwNZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_85AICjYl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_aGndHXoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9DnhkZ8J_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_5PcPvaNu, 0, m, &cIf_5PcPvaNu_sendMessage);
}

void Heavy_WSTD_3Q::cIf_5PcPvaNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_J0E098Ih_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_dt3AIHDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ALpChMdM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_2wkAxd9l_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_NXX55Rhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4xb8GILO, HV_BINOP_POW, 0, m, &cBinop_4xb8GILO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4xb8GILO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gSCdCBow, 0, m, &cIf_gSCdCBow_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KHmiSTP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_KrGpEpyr_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KwlCSsHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_iHdbMRf2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_X0o5tSch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dt3AIHDf, 0, m, &cIf_dt3AIHDf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iHdbMRf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dt3AIHDf, 1, m, &cIf_dt3AIHDf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2wkAxd9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_KHmiSTP2_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ALpChMdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_gSCdCBow, 0, m, &cIf_gSCdCBow_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KrGpEpyr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4xb8GILO, HV_BINOP_POW, 1, m, &cBinop_4xb8GILO_sendMessage);
  cMsg_NXX55Rhv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_gSCdCBow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_TIXPuhze_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_htdLHSqO_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_qzwrMRS0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_9DnhkZ8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5PcPvaNu, 1, m, &cIf_5PcPvaNu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_J0E098Ih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MbYwRA0C, HV_BINOP_GREATER_THAN, 1, m, &cBinop_MbYwRA0C_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tGq437s7, HV_BINOP_EQ, 1, m, &cBinop_tGq437s7_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_BBaWWhjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wPyNHSWN, HV_BINOP_ADD, 0, m, &cBinop_wPyNHSWN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wPyNHSWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KwlCSsHc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X0o5tSch_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MbYwRA0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gSCdCBow, 1, m, &cIf_gSCdCBow_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tGq437s7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2JymY2Il_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_2JymY2Il_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_TIXPuhze_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_htdLHSqO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_qzwrMRS0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_T0EpB9ff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BBaWWhjv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_tr39p44Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aGndHXoQ, 0, m, &cVar_aGndHXoQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QeMnTq5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wPyNHSWN, HV_BINOP_ADD, 1, m, &cBinop_wPyNHSWN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MbYwRA0C, HV_BINOP_GREATER_THAN, 0, m, &cBinop_MbYwRA0C_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tGq437s7, HV_BINOP_EQ, 0, m, &cBinop_tGq437s7_sendMessage);
}

void Heavy_WSTD_3Q::cVar_5tLA1A91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_duSwgZXL_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qyz6vB9p, 0, m, &cIf_qyz6vB9p_sendMessage);
}

void Heavy_WSTD_3Q::cIf_qyz6vB9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kecqOJZ6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_aHZbj0Q8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ReFoYBI8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_H4Bn85n5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_kZfsAkgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qavozisU, HV_BINOP_POW, 0, m, &cBinop_qavozisU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qavozisU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O7SaV4I2, 0, m, &cIf_O7SaV4I2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cwc2ud88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_IDyp7lAz_sendMessage);
}

void Heavy_WSTD_3Q::cCast_eqNlctrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_J5CGRC0p_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rPLCKq6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aHZbj0Q8, 0, m, &cIf_aHZbj0Q8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_J5CGRC0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aHZbj0Q8, 1, m, &cIf_aHZbj0Q8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_H4Bn85n5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_cwc2ud88_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ReFoYBI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_O7SaV4I2, 0, m, &cIf_O7SaV4I2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IDyp7lAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qavozisU, HV_BINOP_POW, 1, m, &cBinop_qavozisU_sendMessage);
  cMsg_kZfsAkgL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_O7SaV4I2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_3ZPAmZ0Q, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_duSwgZXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qyz6vB9p, 1, m, &cIf_qyz6vB9p_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kecqOJZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XXvmuJRk, HV_BINOP_GREATER_THAN, 1, m, &cBinop_XXvmuJRk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bBydKueh, HV_BINOP_EQ, 1, m, &cBinop_bBydKueh_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_zjVgJhXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TNLAIjXa, HV_BINOP_ADD, 0, m, &cBinop_TNLAIjXa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TNLAIjXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eqNlctrc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rPLCKq6n_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XXvmuJRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O7SaV4I2, 1, m, &cIf_O7SaV4I2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bBydKueh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M4B7L4Yw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_M4B7L4Yw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_3ZPAmZ0Q, m);
}

void Heavy_WSTD_3Q::cCast_gPwcMXoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5tLA1A91, 0, m, &cVar_5tLA1A91_sendMessage);
}

void Heavy_WSTD_3Q::cCast_s6XBMeTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TNLAIjXa, HV_BINOP_ADD, 1, m, &cBinop_TNLAIjXa_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XXvmuJRk, HV_BINOP_GREATER_THAN, 0, m, &cBinop_XXvmuJRk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bBydKueh, HV_BINOP_EQ, 0, m, &cBinop_bBydKueh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zCQfEror_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zjVgJhXc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_ECzuJvZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_BrIn9K3S, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_5MibBMKT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4XkxXTw2, 0, m, &cSlice_4XkxXTw2_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cEVT3Ocx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_4XkxXTw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_otvSQwZI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_otvSQwZI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_hckobwao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_otvSQwZI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_otvSQwZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pDWYruV5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_cEVT3Ocx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ky4kLRaG, 0, m, &cSlice_ky4kLRaG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_rtRHGwhU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_ky4kLRaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qLU3QZXj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qLU3QZXj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_tCftTaoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qLU3QZXj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_qLU3QZXj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Z8mez8Mb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_c0EOQrN2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aIESo4OP, 0, m, &cSlice_aIESo4OP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JVEgsp1y_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_aIESo4OP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VXG9ruxp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VXG9ruxp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_wipCLO1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VXG9ruxp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_VXG9ruxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7yJL9a4z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_JVEgsp1y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_keJn3jpK, 0, m, &cSlice_keJn3jpK_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_keJn3jpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vPHfrQBN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vPHfrQBN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_Y3qigsJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vPHfrQBN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_vPHfrQBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_67HGSACL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_nj36Mqd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I7hwoE8y, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_JMu68f3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_w0Pwbzkq, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_9nwTJitx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jwODPWiI, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_14rcNoDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Gt25HlmX, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_y3VtVw8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_26lIDdD7, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_hE4YmDaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IXilJkfI_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_IXilJkfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rwpUd3Zd, HV_BINOP_DIVIDE, 1, m, &cBinop_rwpUd3Zd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TBOYJZCb_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_Rvj931Xb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_utP868Az_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_8MsL4YeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Rvj931Xb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_utP868Az_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rwpUd3Zd, HV_BINOP_DIVIDE, 0, m, &cBinop_rwpUd3Zd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TBOYJZCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8MsL4YeY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_rwpUd3Zd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jauKMDZm, HV_BINOP_MULTIPLY, 1, m, &cBinop_jauKMDZm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jauKMDZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4WwniEur_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qdsw79KF_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_Fbrt8RIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eF8ewyKQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_PkLOmDK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cCMHmzl0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_mlnqTgNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_POSlBOmj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_POSlBOmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jauKMDZm, HV_BINOP_MULTIPLY, 0, m, &cBinop_jauKMDZm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QPGZlUw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_1KMi0gbV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1KMi0gbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hhLLRrI4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_a8uolj6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JdvZUWg2, 1, m, &cVar_JdvZUWg2_sendMessage);
}

void Heavy_WSTD_3Q::cVar_JdvZUWg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ICgWFNmf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_6Hc2YN7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2A5Eij0Y, HV_BINOP_MULTIPLY, 1, m, &cBinop_2A5Eij0Y_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LRwFRjTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6Hc2YN7k_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_30hwd60o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_h02rU6dE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_h02rU6dE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XS98BV6A, HV_BINOP_MULTIPLY, 1, m, &cBinop_XS98BV6A_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HMwpzzRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WZZvItAi, HV_BINOP_MULTIPLY, 1, m, &cBinop_WZZvItAi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_t0qKIjxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HMwpzzRg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6LFYHMhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kUw0IQKb, HV_BINOP_MULTIPLY, 1, m, &cBinop_kUw0IQKb_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_IiUVrSGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gJczXXZ9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gJczXXZ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e58iXSbA, HV_BINOP_MULTIPLY, 1, m, &cBinop_e58iXSbA_sendMessage);
}

void Heavy_WSTD_3Q::cVar_H5qZ6lMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6VzDlMzj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_mlnqTgNm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uNQGZvv3_sendMessage);
}

void Heavy_WSTD_3Q::cVar_fT7z9UJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_QPGZlUw8_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4WwniEur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Fbrt8RIn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qdsw79KF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_PkLOmDK8_sendMessage);
}

void Heavy_WSTD_3Q::cSend_eF8ewyKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rRdPSd2h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_cCMHmzl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GLOjtTGu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_ULqjmkYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3If2TjRj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_hhLLRrI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_OdOirFN0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OdOirFN0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LUuCuSfl, HV_BINOP_MULTIPLY, 1, m, &cBinop_LUuCuSfl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LUuCuSfl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_UZMvgmW1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UZMvgmW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ULqjmkYR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_ICgWFNmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0jMbNmjg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0jMbNmjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cLtY0BAk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YRsUELiu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZMAMLzLV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e8xg9Tw0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RzxWCrqZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_70Z3p7Rd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2A5Eij0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nj36Mqd3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_XS98BV6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JMu68f3q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_WZZvItAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9nwTJitx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_kUw0IQKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_14rcNoDp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_e58iXSbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y3VtVw8p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_3mIYrWxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fT7z9UJ3, 1, m, &cVar_fT7z9UJ3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dnxIiJep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H5qZ6lMC, 0, m, &cVar_H5qZ6lMC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_e8xg9Tw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WZZvItAi, HV_BINOP_MULTIPLY, 0, m, &cBinop_WZZvItAi_sendMessage);
}

void Heavy_WSTD_3Q::cCast_70Z3p7Rd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2A5Eij0Y, HV_BINOP_MULTIPLY, 0, m, &cBinop_2A5Eij0Y_sendMessage);
}

void Heavy_WSTD_3Q::cCast_cLtY0BAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_RzxWCrqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XS98BV6A, HV_BINOP_MULTIPLY, 0, m, &cBinop_XS98BV6A_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZMAMLzLV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kUw0IQKb, HV_BINOP_MULTIPLY, 0, m, &cBinop_kUw0IQKb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_YRsUELiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e58iXSbA, HV_BINOP_MULTIPLY, 0, m, &cBinop_e58iXSbA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_uNQGZvv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JdvZUWg2, 0, m, &cVar_JdvZUWg2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6VzDlMzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fT7z9UJ3, 0, m, &cVar_fT7z9UJ3_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_pIe8z99m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rAIke8YP, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_dqQZDRA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NmFyk9xE, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_wuGb2KgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SGLRmN8v, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_IueCaYZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0ndUEwve, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_jUluczVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JoqR7H98_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_JoqR7H98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9GGD1mRS, HV_BINOP_DIVIDE, 1, m, &cBinop_9GGD1mRS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wGlS3cEk_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_eOUhAmBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_up0LDWes_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_lgyaCUzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_eOUhAmBJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_up0LDWes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9GGD1mRS, HV_BINOP_DIVIDE, 0, m, &cBinop_9GGD1mRS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_wGlS3cEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lgyaCUzS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_9GGD1mRS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MeHYnA4b, HV_BINOP_MULTIPLY, 1, m, &cBinop_MeHYnA4b_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MeHYnA4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UnyDzYPR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LFlbuNZU_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_kX1uzi3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xSn4uZhy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_KO75aeLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ReRMJs2m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Ao7EOnhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_CimvbX5i_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CimvbX5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MeHYnA4b, HV_BINOP_MULTIPLY, 0, m, &cBinop_MeHYnA4b_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pz37P1l0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_hCj2HJ77_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hCj2HJ77_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kPrElmdT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_pxzT2AiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3LtrYC24, HV_BINOP_MULTIPLY, 1, m, &cBinop_3LtrYC24_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fLo6Pr0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UtdxR2jt, 1, m, &cVar_UtdxR2jt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5jl0lw4A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_92Ktd29H, HV_BINOP_MULTIPLY, 1, m, &cBinop_92Ktd29H_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_VgIMbLFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_VuZG26U0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VuZG26U0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s00l4tke, HV_BINOP_MULTIPLY, 1, m, &cBinop_s00l4tke_sendMessage);
}

void Heavy_WSTD_3Q::cVar_UtdxR2jt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OQzKP7Nl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_dmHTAZx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6GD2e5Nc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Ao7EOnhj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6DC7pQxS_sendMessage);
}

void Heavy_WSTD_3Q::cVar_GuzmVPNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_pz37P1l0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_UnyDzYPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_kX1uzi3M_sendMessage);
}

void Heavy_WSTD_3Q::cCast_LFlbuNZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_KO75aeLS_sendMessage);
}

void Heavy_WSTD_3Q::cSend_xSn4uZhy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hMa4mTR2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_ReRMJs2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1LB4kwFw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_TlICQb22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SNX3asYW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_kPrElmdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Rx5xBBnW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Rx5xBBnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6usUjnpT, HV_BINOP_MULTIPLY, 1, m, &cBinop_6usUjnpT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6usUjnpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZovJl7xW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZovJl7xW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TlICQb22_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_OQzKP7Nl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zH54a3uS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zH54a3uS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_96WdwL6s_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_weWttrAY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LXPC2MkB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7p8ZNdDv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QJcQHYL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pIe8z99m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_3LtrYC24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dqQZDRA0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_92Ktd29H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wuGb2KgT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_s00l4tke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IueCaYZn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_GbaMFKW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dmHTAZx9, 0, m, &cVar_dmHTAZx9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_waURp0gK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GuzmVPNU, 1, m, &cVar_GuzmVPNU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6DC7pQxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UtdxR2jt, 0, m, &cVar_UtdxR2jt_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6GD2e5Nc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GuzmVPNU, 0, m, &cVar_GuzmVPNU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7p8ZNdDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QJcQHYL0, HV_BINOP_MULTIPLY, 0, m, &cBinop_QJcQHYL0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_weWttrAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_92Ktd29H, HV_BINOP_MULTIPLY, 0, m, &cBinop_92Ktd29H_sendMessage);
}

void Heavy_WSTD_3Q::cCast_96WdwL6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s00l4tke, HV_BINOP_MULTIPLY, 0, m, &cBinop_s00l4tke_sendMessage);
}

void Heavy_WSTD_3Q::cCast_LXPC2MkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3LtrYC24, HV_BINOP_MULTIPLY, 0, m, &cBinop_3LtrYC24_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_UNnGqkbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iYK0Mw9A, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_QqVkRmAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ie1TZBzw, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_igKgbNPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Z3vvWvgs, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_y1GFTc4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CcnaJ4Ex, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Kiz7XWPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L7tnfZDQ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_NrOqlg5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lKxY2ve8_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_lKxY2ve8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BAA2LSoN, HV_BINOP_DIVIDE, 1, m, &cBinop_BAA2LSoN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PK5Tmgaf_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_26OpIcLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_XrA2LFa9_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ZNuvAHYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_26OpIcLt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XrA2LFa9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BAA2LSoN, HV_BINOP_DIVIDE, 0, m, &cBinop_BAA2LSoN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PK5Tmgaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZNuvAHYA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_BAA2LSoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SDbyB1r7, HV_BINOP_MULTIPLY, 1, m, &cBinop_SDbyB1r7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SDbyB1r7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2P4FHBDw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hF8pzdXm_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_CSDT6ifU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_P0eEmcJy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_Dzeif7nx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kPH3gTuE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_lqEpwUqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Rzy3WLti_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Rzy3WLti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SDbyB1r7, HV_BINOP_MULTIPLY, 0, m, &cBinop_SDbyB1r7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3d9v9Xcb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_MTymP76J_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MTymP76J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lA0Nq2kt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_YibmEURJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GIEyP9B0, HV_BINOP_MULTIPLY, 1, m, &cBinop_GIEyP9B0_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_UMWj3TOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_0p5JVyRR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0p5JVyRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YibmEURJ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_NOECv487_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gRZ2BypM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gRZ2BypM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wl20k4VL, HV_BINOP_MULTIPLY, 1, m, &cBinop_wl20k4VL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Mi4B3S4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NKaK6w32, HV_BINOP_MULTIPLY, 1, m, &cBinop_NKaK6w32_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_V4MtECvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_dddBDJHg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dddBDJHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Mi4B3S4i_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xdplpNl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EszGlR5I, 1, m, &cVar_EszGlR5I_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qpj4gnNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uHGc1W7B, HV_BINOP_MULTIPLY, 1, m, &cBinop_uHGc1W7B_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_j4rQswEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QZgTraHk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QZgTraHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sa0r9GBI, HV_BINOP_MULTIPLY, 1, m, &cBinop_sa0r9GBI_sendMessage);
}

void Heavy_WSTD_3Q::cVar_EszGlR5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LOinEyow_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_zXGqFjQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BiYL51Q6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_lqEpwUqb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SYC05m5Y_sendMessage);
}

void Heavy_WSTD_3Q::cVar_dHeJODCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_3d9v9Xcb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_hF8pzdXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_Dzeif7nx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2P4FHBDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_CSDT6ifU_sendMessage);
}

void Heavy_WSTD_3Q::cSend_P0eEmcJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xYjD0iqC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_kPH3gTuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ABNeBZCK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_iW4iUUjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Se0RsNFt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_lA0Nq2kt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_EvD5o6Aa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EvD5o6Aa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PSUooRHR, HV_BINOP_MULTIPLY, 1, m, &cBinop_PSUooRHR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PSUooRHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_m8RCg67c_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_m8RCg67c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iW4iUUjv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_LOinEyow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0SdNVL14_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0SdNVL14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OyPW2CCg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7AnrnJCL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RKFOpARX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e58OEQrh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_erKGFCLp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xeBOv25g_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GIEyP9B0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UNnGqkbG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_wl20k4VL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QqVkRmAF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_NKaK6w32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_igKgbNPP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_uHGc1W7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y1GFTc4w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_sa0r9GBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kiz7XWPa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_SPfwY9vI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dHeJODCz, 1, m, &cVar_dHeJODCz_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KXBdHrOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zXGqFjQN, 0, m, &cVar_zXGqFjQN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_RKFOpARX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uHGc1W7B, HV_BINOP_MULTIPLY, 0, m, &cBinop_uHGc1W7B_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xeBOv25g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GIEyP9B0, HV_BINOP_MULTIPLY, 0, m, &cBinop_GIEyP9B0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7AnrnJCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sa0r9GBI, HV_BINOP_MULTIPLY, 0, m, &cBinop_sa0r9GBI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_OyPW2CCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_erKGFCLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wl20k4VL, HV_BINOP_MULTIPLY, 0, m, &cBinop_wl20k4VL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_e58OEQrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NKaK6w32, HV_BINOP_MULTIPLY, 0, m, &cBinop_NKaK6w32_sendMessage);
}

void Heavy_WSTD_3Q::cCast_SYC05m5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EszGlR5I, 0, m, &cVar_EszGlR5I_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BiYL51Q6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dHeJODCz, 0, m, &cVar_dHeJODCz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TIXPuhze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ECzuJvZC, 1, m, &cIf_ECzuJvZC_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_8r7M7xlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BrIn9K3S, m);
}

void Heavy_WSTD_3Q::cBinop_htdLHSqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8r7M7xlm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_qzwrMRS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ECzuJvZC, 0, m, &cIf_ECzuJvZC_sendMessage);
}

void Heavy_WSTD_3Q::cVar_MJ7bsSBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xFUbW4WF, HV_BINOP_DIVIDE, 0, m, &cBinop_xFUbW4WF_sendMessage);
}

void Heavy_WSTD_3Q::cVar_S3cMBvEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MGULSpPX, HV_BINOP_DIVIDE, 1, m, &cBinop_MGULSpPX_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xFUbW4WF, HV_BINOP_DIVIDE, 1, m, &cBinop_xFUbW4WF_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_GNo1QtUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pOlNGK8i, HV_BINOP_DIVIDE, 0, m, &cBinop_pOlNGK8i_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_U8Xp1rTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pOlNGK8i, HV_BINOP_DIVIDE, 1, m, &cBinop_pOlNGK8i_sendMessage);
}

void Heavy_WSTD_3Q::cCast_n5XxC71M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MGULSpPX, HV_BINOP_DIVIDE, 0, m, &cBinop_MGULSpPX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rd4Sbo0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S3cMBvEj, 0, m, &cVar_S3cMBvEj_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VXnQcPeH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MJ7bsSBf, 0, m, &cVar_MJ7bsSBf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MGULSpPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_GNo1QtUm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xFUbW4WF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_U8Xp1rTx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pOlNGK8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_G4NWpP1c_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_0jKw7mI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_r5OCWNu3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QJeUcO1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_3whfl2k6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_G4NWpP1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_QJeUcO1K_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3whfl2k6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_0jKw7mI2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_r5OCWNu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xCLWRGTv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_3QKzTCq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_13Goj8qS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_5MibBMKT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_qFHsjrrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_13Goj8qS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_5MibBMKT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_KgAXFtJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_13Goj8qS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_5MibBMKT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_uAqeWiu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_13Goj8qS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_5MibBMKT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_xCLWRGTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_13Goj8qS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_5MibBMKT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_vLa7v3xh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_FgWI582P, 0, m, &cVar_FgWI582P_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_fmWkQxHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_35jiVoDp, 0, m, &cVar_35jiVoDp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rTaQUM2Y, 0, m, &cVar_rTaQUM2Y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2J2YYuHz, 0, m, &cVar_2J2YYuHz_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_IX3jnT5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_35jiVoDp, 0, m, &cVar_35jiVoDp_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_kfGaRJdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rTaQUM2Y, 0, m, &cVar_rTaQUM2Y_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_RcxbrAD1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2J2YYuHz, 0, m, &cVar_2J2YYuHz_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_eXrOYwB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_L80f7Lq4, 0, m, &cVar_L80f7Lq4_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_1oN7x6HA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_elos98Hk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7vH5f0Ql_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_quTNmeA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YCDxk4jP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wIfUkiTX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KJWBaAm7_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_1S9gv0Jq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cjoJNF8k_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b7id82Qe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NMyt1sMy_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_VBnv8PAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TE0hWuFi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A23e1Wt2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IPGzfuuf_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_PCfeeOoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b0Zp1n3h_sendMessage(_c, 0, m);
  cMsg_0PnzQOq5_sendMessage(_c, 0, m);
  cMsg_GvKkYBHq_sendMessage(_c, 0, m);
  cMsg_hE4YmDaI_sendMessage(_c, 0, m);
  cMsg_jUluczVB_sendMessage(_c, 0, m);
  cMsg_NrOqlg5y_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uBdm1D1T, 0, m, &cVar_uBdm1D1T_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_L80f7Lq4, 0, m, &cVar_L80f7Lq4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_quelAiIa, 0, m, &cVar_quelAiIa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_H5qZ6lMC, 0, m, &cVar_H5qZ6lMC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dmHTAZx9, 0, m, &cVar_dmHTAZx9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zXGqFjQN, 0, m, &cVar_zXGqFjQN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CwAX2thZ, 0, m, &cVar_CwAX2thZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lLOD0VAU, 0, m, &cVar_lLOD0VAU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RZyVcJhy, 0, m, &cVar_RZyVcJhy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vcDBbsZw, 0, m, &cVar_vcDBbsZw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZOsv9dwg, 0, m, &cVar_ZOsv9dwg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pCEforIK, 0, m, &cVar_pCEforIK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vzmfNFSc, 0, m, &cVar_vzmfNFSc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hUBZz1FT, 0, m, &cVar_hUBZz1FT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MLmOMhgH, 0, m, &cVar_MLmOMhgH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jI2Bt3XH, 0, m, &cVar_jI2Bt3XH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aGndHXoQ, 0, m, &cVar_aGndHXoQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5tLA1A91, 0, m, &cVar_5tLA1A91_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hckobwao, 0, m, &cVar_hckobwao_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tCftTaoj, 0, m, &cVar_tCftTaoj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wipCLO1P, 0, m, &cVar_wipCLO1P_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Y3qigsJd, 0, m, &cVar_Y3qigsJd_sendMessage);
  cMsg_fmWkQxHN_sendMessage(_c, 0, m);
  cMsg_vLa7v3xh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_MaIm6KIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CQ24WrF3, HV_BINOP_MULTIPLY, 0, m, &cBinop_CQ24WrF3_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ZBjtXVW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qaFOePTO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_LtMyUSOM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_M13O2YrF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_PSiPnIeG_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_zQsbEgWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jrxJcsfZ_sendMessage);
  cMsg_PHRvcuge_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_lE7jqGYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b9uvRujC, HV_BINOP_MULTIPLY, 0, m, &cBinop_b9uvRujC_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_DLogvRyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_YvOBrzE3_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_6itgj6Wy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aNNg9LQd, HV_BINOP_MULTIPLY, 1, m, &cBinop_aNNg9LQd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_o5NHEm4N_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_uJve27a2_sendMessage);
  cMsg_lGbQqbet_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_TyfvJGza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nrNTwTYx, HV_BINOP_MULTIPLY, 0, m, &cBinop_nrNTwTYx_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_8XHo6kNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uixrIlCN_sendMessage(_c, 0, m);
  cMsg_jefOKAhh_sendMessage(_c, 0, m);
  cMsg_tGcAKG5l_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_8y4bYaWD_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_NLZb45dK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_CAmzgc6s_sendMessage);
  cMsg_r4V3CACJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_sJT1hcyi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dmHTAZx9, 0, m, &cVar_dmHTAZx9_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_67HGSACL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_waURp0gK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GbaMFKW2_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_pDWYruV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bpcFiTHq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_apB8sDeI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0K1iwNZs_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_7yJL9a4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gPwcMXoD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s6XBMeTq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zCQfEror_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Z8mez8Mb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tr39p44Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QeMnTq5a_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T0EpB9ff_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_rRdPSd2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LUuCuSfl, HV_BINOP_MULTIPLY, 0, m, &cBinop_LUuCuSfl_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_GLOjtTGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_LRwFRjTn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_30hwd60o_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_t0qKIjxx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_6LFYHMhs_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_3If2TjRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_a8uolj6C_sendMessage);
  cMsg_IiUVrSGD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_hMa4mTR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6usUjnpT, HV_BINOP_MULTIPLY, 0, m, &cBinop_6usUjnpT_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_1LB4kwFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_5jl0lw4A_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_SNX3asYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QJcQHYL0, HV_BINOP_MULTIPLY, 1, m, &cBinop_QJcQHYL0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_pxzT2AiT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_fLo6Pr0Q_sendMessage);
  cMsg_VgIMbLFG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_xYjD0iqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PSUooRHR, HV_BINOP_MULTIPLY, 0, m, &cBinop_PSUooRHR_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ABNeBZCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UMWj3TOW_sendMessage(_c, 0, m);
  cMsg_NOECv487_sendMessage(_c, 0, m);
  cMsg_V4MtECvX_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_qpj4gnNU_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Se0RsNFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xdplpNl8_sendMessage);
  cMsg_j4rQswEs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_PlVTtVTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FgWI582P, 0, m, &cVar_FgWI582P_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_3Q::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9;

  // input and output vars
  hv_bufferf_t O0, O1, O2, O3, O4, O5;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));
    __hv_zero_f(VOf(O2));
    __hv_zero_f(VOf(O3));
    __hv_zero_f(VOf(O4));
    __hv_zero_f(VOf(O5));

    // process all signal functions
    __hv_line_f(&sLine_juIJ1bq3, VOf(Bf0));
    __hv_line_f(&sLine_HSBlfto4, VOf(Bf1));
    __hv_line_f(&sLine_k3cMVEUZ, VOf(Bf2));
    __hv_line_f(&sLine_mC5qFVyT, VOf(Bf3));
    __hv_line_f(&sLine_zxaTfkul, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_FaEjAeYp, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_zDlEnLIJ, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_5UTUSTPe, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_0dv8q0TN, VOf(Bf1));
    __hv_line_f(&sLine_10gBQTkR, VOf(Bf0));
    __hv_line_f(&sLine_A0WDN8Yk, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_GejiYPJV, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_iaclqBH2, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_2kjBMG0s, VOf(Bf5));
    __hv_line_f(&sLine_J1GxVKre, VOf(Bf1));
    __hv_line_f(&sLine_NtFUxcRi, VOf(Bf2));
    __hv_line_f(&sLine_zKKNZFmj, VOf(Bf4));
    __hv_line_f(&sLine_oEfaW6mc, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_uMocLMLe, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_XM2d77zl, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_I7hwoE8y, VOf(Bf6));
    __hv_line_f(&sLine_w0Pwbzkq, VOf(Bf2));
    __hv_line_f(&sLine_jwODPWiI, VOf(Bf1));
    __hv_line_f(&sLine_Gt25HlmX, VOf(Bf5));
    __hv_line_f(&sLine_26lIDdD7, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_76qvNynj, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_JBiaEqTC, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_rAIke8YP, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_NmFyk9xE, VOf(Bf2));
    __hv_line_f(&sLine_SGLRmN8v, VOf(Bf6));
    __hv_line_f(&sLine_0ndUEwve, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_4EkTAIb9, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_BrIn9K3S, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_iYK0Mw9A, VOf(Bf8));
    __hv_line_f(&sLine_ie1TZBzw, VOf(Bf2));
    __hv_line_f(&sLine_Z3vvWvgs, VOf(Bf1));
    __hv_line_f(&sLine_CcnaJ4Ex, VOf(Bf7));
    __hv_line_f(&sLine_L7tnfZDQ, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_awTxZnc4, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_3ZPAmZ0Q, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf4), VIf(O4), VOf(O4));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf6), VIf(O3), VOf(O3));
    __hv_add_f(VIf(Bf7), VIf(O5), VOf(O5));
    __hv_add_f(VIf(Bf0), VIf(O2), VOf(O2));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
    __hv_store_f(outputBuffers[2]+n, VIf(O2));
    __hv_store_f(outputBuffers[3]+n, VIf(O3));
    __hv_store_f(outputBuffers[4]+n, VIf(O4));
    __hv_store_f(outputBuffers[5]+n, VIf(O5));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_3Q::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 6 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(6*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);
  bOut[2] = outputBuffers+(2*n4);
  bOut[3] = outputBuffers+(3*n4);
  bOut[4] = outputBuffers+(4*n4);
  bOut[5] = outputBuffers+(5*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_3Q::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 6 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(6*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  
  // interleave the heavy output into the output buffer
  for (int i = 0; i < 6; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+6*j] = bOut[i*n4+j];
    }
  }

  return n;
}
